@@ -57,7 +57,7 @@ use PPIx::Regexp::Util qw{
 
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.075';
+our $VERSION = '0.080';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
@@ -223,6 +223,10 @@ sub cookie {
     my ( $self, $name, @args ) = @_;
     defined $name
 	or confess "Programming error - undefined cookie name";
+    if ( $self->{trace} ) {
+	local $" = ', ';
+	warn "cookie( '$name', @args )\n";
+    }
     @args or return $self->{cookie}{$name};
     my $cookie = shift @args;
     if ( CODE_REF eq ref $cookie ) {
@@ -234,6 +238,20 @@ sub cookie {
     }
 }
 
+# NOTE: Currently this is called only against
+# COOKIE_LOOKAROUND_ASSERTION, once in PPIx::Token::GroupType::Assertion
+# to prevent the cookie from being remade if it already exists, and once
+# in PPIx::Regexp::Token::Assertion to determine if \K is inside a
+# lookaround assertion. If it gets used other places, or if there is
+# call for it, I should consider removing the underscores and
+# documenting it as public.
+sub __cookie_exists {
+    my ( $self, $name ) = @_;
+    defined $name
+	or confess "Programming error - undefined cookie name";
+    return $self->{cookie}{$name};
+}
+
 sub default_modifiers {
     my ( $self ) = @_;
     return [ @{ $self->{default_modifiers} } ];
@@ -757,7 +775,7 @@ sub tokens {
 
     my %deprecate = (
 	attribute => {
-	    postderef	=> 1,
+	    postderef	=> 2,
 	},
     );
 
@@ -1709,7 +1727,9 @@ troubleshoot funny output from the tokenizer.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1717,7 +1737,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
